CurrencyLink class

Annotations
  • @JsonSerializable.new()

Constructors

CurrencyLink({required String href, TargetHints? targetHints})
CurrencyLink.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
href String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetHints TargetHints?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited