TextSetting class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

TextSetting({required String id, required String label, required String description, required String value, required String default_, required String tip, required String placeholder, dynamic options})
TextSetting.fromJson(Map<String, dynamic> json)
factory

Properties

default_ String
final
description String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
id String
finalinherited
label String
finalinherited
options → dynamic
finalinherited
placeholder String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tip String
finalinherited
type String
finalinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited