WooBilling class

Constructors

WooBilling({String? firstName, String? lastName, String? company, String? address1, String? address2, String? city, String? state, String? postcode, String? country, String? email, String? phone})
WooBilling.fake()
factory
WooBilling.fromJson(Map<String, dynamic> json)

Properties

address1 String?
Address line 1
getter/setter pair
address2 String?
Address line 2
getter/setter pair
city String?
City name.
getter/setter pair
company String?
Company name.
getter/setter pair
country String?
Country code in ISO 3166-1 alpha-2 format.
getter/setter pair
email String?
Email address.
getter/setter pair
firstName String?
First name.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lastName String?
Last name.
getter/setter pair
phone String?
Phone number.
getter/setter pair
postcode String?
Postal code.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
ISO code or name of the state, province or district.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited