WooCartItem class

Annotations
  • @JsonSerializable.new()

Constructors

WooCartItem({String? key, int? id, int? quantity, String? name, String? sku, String? permalink, List<WooProductImage>? images, double? price, double? linePrice, List<int>? variations, List<String>? tags, bool? userSalePrice})
WooCartItem.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id int?
Product ID.
getter/setter pair
images List<WooProductImage>?
Cart Item images.
getter/setter pair
key String?
Cart Item Key.
getter/setter pair
linePrice double?
Cart Item line price.
getter/setter pair
name String?
Cart Item name.
getter/setter pair
Product URL.
getter/setter pair
price double?
Cart Item price.
getter/setter pair
quantity int?
Cart Item quantity.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sku String?
Unique identifier.
getter/setter pair
tags List<String>?
getter/setter pair
userSalePrice bool?
getter/setter pair
variations List<int>?
Cart Item variations.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fake() WooCartItem