WooProductAttribute class

Annotations
  • @JsonSerializable.new()

Constructors

WooProductAttribute({int? id, String? name, String? slug, String? type, String? orderBy, bool? hasArchives, WooProductAttributeLinks? links})
WooProductAttribute.fromJson(Map<String, dynamic> json)
factory

Properties

hasArchives bool?
final
hashCode int
The hash code for this object.
no setterinherited
id int?
final
final
name String?
final
orderBy String?
Sort order of terms. name | id | menu_order
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slug String?
final
type String?
Type of attribute. Ex: select
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fake() WooProductAttribute