WooProductAttributeLinks class

Annotations
  • @JsonSerializable.new()

Constructors

WooProductAttributeLinks({List<Map<String, dynamic>>? self, List<Map<String, dynamic>>? collection})
WooProductAttributeLinks.fromJson(Map<String, dynamic> json)
factory

Properties

collection List<Map<String, dynamic>>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self List<Map<String, dynamic>>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fake() WooProductAttributeLinks