WooProductCategory class

Annotations
  • @JsonSerializable.new()

Constructors

WooProductCategory({int? id, String? name, String? slug, int? parent, String? description, WooCategoryDisplay? display, WooProductCategoryImage? image, int? menuOrder, int? count, WooProductCategoryLinks? links})
WooProductCategory.fromJson(Map<String, dynamic> json)
factory

Properties

count int?
Number of published products for the resource.
final
description String?
HTML description of the resource.
final
display WooCategoryDisplay?
Category archive display type. Options: default, products, subcategories and both. Default is default.
final
hashCode int
The hash code for this object.
no setterinherited
id int?
Unique identifier for the resource.
final
image WooProductCategoryImage?
Image data.
final
Links to related resources.
final
Menu order, used to custom sort the resource.
final
name String?
Category name.
final
parent int?
The ID for the parent of the resource.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slug String?
An alphanumeric identifier for the resource unique to its type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fake() WooProductCategory