WooProductItemAttribute class
- Annotations
-
- @JsonSerializable.new()
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int?
-
Attribute ID.
final
- name → String?
-
Attribute name.
final
-
options
→ List<
String> ? -
List of available terms.
final
- position → int?
-
Attribute position.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- variation → bool?
-
Is attribute used for variations.
final
- visible → bool?
-
Is attribute visible on product page.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited