WooProductVariation class

Annotations
  • @JsonSerializable.new()

Constructors

WooProductVariation({int? id, String? dateCreated, String? dateModified, String? description, String? permalink, String? sku, String? price, String? regularPrice, String? salePrice, String? dateOnSaleFrom, String? dateOnSaleTo, bool? onSale, bool? purchasable, bool? virtual, bool? downloadable, List<WooProductDownload>? downloads, int? downloadLimit, int? downloadExpiry, String? taxStatus, String? taxClass, bool? manageStock, int? stockQuantity, String? stockStatus, String? backorders, bool? backordersAllowed, bool? backordered, String? weight, WooProductDimension? dimensions, String? shippingClass, int? shippingClassId, Map<String, dynamic>? image, List<Map<String, dynamic>>? attributes, int? menuOrder, List<Map<String, dynamic>>? metaData})
WooProductVariation.fromJson(Map<String, dynamic> json)
factory

Properties

attributes List<Map<String, dynamic>>?
List of attributes.
final
backordered bool?
Shows if the variation is on backordered.
final
backorders String?
If managing stock, this controls if backorders are allowed.
final
backordersAllowed bool?
Shows if backorders are allowed.
final
dateCreated String?
The date the variation was created, in the site's timezone.
final
dateModified String?
The date the variation was last modified, in the site's timezone.
final
dateOnSaleFrom String?
Start date of sale price, in the site's timezone.
final
dateOnSaleTo String?
End date of sale price, in the site's timezone.
final
description String?
Variation description.
final
dimensions WooProductDimension?
Variation dimensions.
final
downloadable bool?
If the variation is downloadable.
final
downloadExpiry int?
Number of days until access to downloadable files expires.
final
downloadLimit int?
Number of times downloadable files can be downloaded after purchase.
final
downloads List<WooProductDownload>?
List of downloadable files.
final
hashCode int
The hash code for this object.
no setterinherited
id int?
Unique identifier for the resource.
final
image Map<String, dynamic>?
Variation image data.
final
manageStock bool?
Stock management at variation level.
final
Menu order, used to custom sort variations.
final
metaData List<Map<String, dynamic>>?
Meta data.
final
onSale bool?
Shows if the variation is on sale.
final
Variation URL.
final
price String?
Current variation price.
final
purchasable bool?
Shows if the variation can be bought.
final
regularPrice String?
Variation regular price.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
salePrice String?
Variation sale price.
final
shippingClass String?
Shipping class slug.
final
shippingClassId int?
Shipping class ID.
final
sku String?
Unique identifier.
final
stockQuantity int?
Stock quantity.
final
stockStatus String?
Controls whether or not the variation is listed as "in stock" or "out of stock" on the frontend.
final
taxClass String?
Tax class.
final
taxStatus String?
Tax status.
final
virtual bool?
If the variation is virtual.
final
weight String?
Variation weight.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fake() WooProductVariation