dateCreated property
The date the variation was created, in the site's timezone.
Implementation
@JsonKey(name: 'date_created')
final String? dateCreated;
The date the variation was created, in the site's timezone.
@JsonKey(name: 'date_created')
final String? dateCreated;