WooShippingLine class

Constructors

WooShippingLine({int? id, String? methodTitle, String? methodId, double? total, double? totalTax, List<WooTax>? taxes, List<WooMetaData>? metaData})
WooShippingLine.fake()
factory
WooShippingLine.fromJson(Map<String, dynamic> json)

Properties

hashCode int
The hash code for this object.
no setterinherited
id int?
Item ID.
getter/setter pair
metaData List<WooMetaData>?
Meta data.
getter/setter pair
methodId String?
Shipping method ID.
getter/setter pair
methodTitle String?
Shipping method name.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
taxes List<WooTax>?
Line taxes.
getter/setter pair
total double?
Line total (after discounts).
getter/setter pair
totalTax double?
Line total tax (after discounts).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited