StoreCartTotals class
- Annotations
-
- @JsonSerializable.new(includeIfNull: false)
Constructors
- StoreCartTotals({String? totalItems, String? totalItemsTax, String? totalFees, String? totalFeesTax, String? totalDiscount, String? totalDiscountTax, String? totalShipping, String? totalShippingTax, String? totalPrice, String? totalTax, String? lineSubtotal, String? lineSubtotalTax, String? lineTotal, String? lineTotalTax, String? currencyCode, String? currencySymbol, int? currencyMinorUnit, String? currencyDecimalSeparator, String? currencyThousandSeparator, String? currencyPrefix, String? currencySuffix})
-
StoreCartTotals.fromJson(Map<
String, dynamic> json) -
factory
Properties
- currencyCode ↔ String?
-
Currency code
getter/setter pair
- currencyDecimalSeparator ↔ String?
-
Currency decimal separator
getter/setter pair
- currencyMinorUnit ↔ int?
-
Currency minor unit
getter/setter pair
- currencyPrefix ↔ String?
-
Currency prefix
getter/setter pair
- currencySuffix ↔ String?
-
Currency suffix
getter/setter pair
- currencySymbol ↔ String?
-
Currency symbol
getter/setter pair
- currencyThousandSeparator ↔ String?
-
Currency thousand separator
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- lineSubtotal ↔ String?
-
Line subtotal (item-level)
getter/setter pair
- lineSubtotalTax ↔ String?
-
Line subtotal tax (item-level)
getter/setter pair
- lineTotal ↔ String?
-
Line total (item-level)
getter/setter pair
- lineTotalTax ↔ String?
-
Line total tax (item-level)
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalDiscount ↔ String?
-
Total discount (cart-level)
getter/setter pair
- totalDiscountTax ↔ String?
-
Total discount tax (cart-level)
getter/setter pair
- totalFees ↔ String?
-
Total fees (cart-level)
getter/setter pair
- totalFeesTax ↔ String?
-
Total fees tax (cart-level)
getter/setter pair
- totalItems ↔ String?
-
Total items (cart-level)
getter/setter pair
- totalItemsTax ↔ String?
-
Total items tax (cart-level)
getter/setter pair
- totalPrice ↔ String?
-
Total price (cart-level)
getter/setter pair
- totalShipping ↔ String?
-
Total shipping (cart-level)
getter/setter pair
- totalShippingTax ↔ String?
-
Total shipping tax (cart-level)
getter/setter pair
- totalTax ↔ String?
-
Total tax (cart-level)
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fake(
) → StoreCartTotals