WooOrderStatus enum
Values
- any → const WooOrderStatus
- pending → const WooOrderStatus
- processing → const WooOrderStatus
- onHold → const WooOrderStatus
- completed → const WooOrderStatus
- cancelled → const WooOrderStatus
- refunded → const WooOrderStatus
- failed → const WooOrderStatus
- trash → const WooOrderStatus
- draft → const WooOrderStatus
- underReview → const WooOrderStatus
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fake(
) → WooOrderStatus -
fromString(
String type) → WooOrderStatus -
toValue(
WooOrderStatus? s) → String - Convert enum to WooCommerce string
Constants
-
values
→ const List<
WooOrderStatus> - A constant List of the values in this enum, in order of their declaration.