WooProductCategory class
Properties
-
count
→ int?
-
Number of published products for the resource.
final
-
description
→ String?
-
HTML description of the resource.
final
-
display
→ WooCategoryDisplay?
-
Category archive display type. Options: default, products, subcategories and both. Default is default.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
id
→ int?
-
Unique identifier for the resource.
final
-
image
→ WooProductCategoryImage?
-
Image data.
final
-
links
→ WooProductCategoryLinks?
-
Links to related resources.
final
-
Menu order, used to custom sort the resource.
final
-
name
→ String?
-
Category name.
final
-
parent
→ int?
-
The ID for the parent of the resource.
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
slug
→ String?
-
An alphanumeric identifier for the resource unique to its type.
final