WooProductCategoryImage class
- Annotations
-
- @JsonSerializable.new()
Constructors
Properties
- alt → String?
-
Image alternative text.
final
- dateCreated → DateTime?
-
The date the image was created, in the site's timezone.
final
- dateCreatedGmt → DateTime?
-
The date the image was created, as GMT.
final
- dateModified → DateTime?
-
The date the image was last modified, in the site's timezone.
final
- dateModifiedGmt → DateTime?
-
The date the image was last modified, as GMT.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int?
-
Image ID.
final
- name → String?
-
Image name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- src → String?
-
Image URL.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited